@@ -166,29 +166,28 @@ def check_if_mr_is_valid(project, source_branch, target_branch):
         )
         sys.exit(1)
 
-    exists = does_mr_exists(project, source_branch)
+    exists = does_mr_exists(project, source_branch, target_branch)
     if exists:
-        print(f"no new merge request opened, one already exists for this branch {source_branch}.")
+        print(f"no new merge request opened, one already exists for this branch {source_branch} to {target_branch}.")
         sys.exit(0)
 
 
-def does_mr_exists(project, source_branch):
-    """Checks if an MR for the source branch (i.e. feature/abc) already exists.
+def does_mr_exists(project, source_branch, target_branch):
+    """Checks if an MR for the source branch (i.e. feature/abc) to the target branch (i.e. develop) already exists.
 
     Args:
         project (gitlab.v4.objects.Project): The json response from API checking which MRs are currently open.
         source_branch (str): The source branch to merge into (i.e. feature/#67).
+        target_branch (str): The target branch to merge onto (i.e. develop).
 
     Returns
         bool: True if the MR already exists, else returns False.
 
     """
     mrs = project.mergerequests.list(state="opened")
-    exists = False
-    source_branch_mr = [mr for mr in mrs if mr.source_branch == source_branch]
-    if source_branch_mr:
-        exists = True
-    return exists
+    existing_mr = [mr for mr in mrs if mr.source_branch == source_branch and mr.target_branch == target_branch]
+
+    return True if existing_mr else False
 
 
 def get_description_data(description):
